/*
 * Worldcup is Copyright (c) 2001,2002 by Thomas Pundt
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose, without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice and this paragraph and the
 * following two paragraphs appear in all copies.
 *
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT,
 * SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, INCLUDING LOST PROFITS,
 * ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF
 * THE AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"
 * BASIS, AND THE AUTHOR HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#include <PalmOS.h>

#include "worldcup.h"
#include "worldcuprcp.h"

static char* items[25] = { 0, };
static Int16 selectedPlayer;

/**
 * Teams Form
 */
Boolean TeamsFormHandleEvent(EventPtr e)
{
  Boolean handled;
  static FormPtr frm;
  ListPtr p;
  FieldPtr fld;
  UInt16 nrOfItems;
  RectangleType rect;
  struct team* team;
  void *hBmp;

  handled = false;
  switch (e->eType) {

  case frmOpenEvent:
    frm = FrmGetActiveForm();
    team = GetTeamString(selectedTeam);
    FrmCopyTitle(frm,team->name);
    nrOfItems = readPlayers(items,selectedTeam);
    p = FrmGetObjectPtr(frm, FrmGetObjectIndex(frm, IdFrmTeams+1));
    LstSetListChoices(p, items, nrOfItems);
    LstSetHeight(p, nrOfItems>8?8:nrOfItems);

    fld = FrmGetObjectPtr(frm, FrmGetObjectIndex(frm, IdFrmTeams+2));
    FldSetTextPtr(fld, team->info);
    FldRecalculateField(fld,true);
    FldGetBounds(fld, &rect);
    rect.extent.y = FldCalcFieldHeight(team->info,rect.extent.x)*FntLineHeight();
    FldSetBounds(fld, &rect);

    FrmDrawForm(frm);

    if ( (hBmp = DmGetResource((UInt32)'Tbmp',IdFlag+selectedTeam)) ) {
      WinDrawBitmap(MemHandleLock(hBmp),1,13);
      MemHandleUnlock(hBmp);
      DmReleaseResource(hBmp);
    }
    handled = true; 
    break;

  case ctlSelectEvent:
    if (e->data.ctlSelect.controlID == IdFrmTeams) {
      FrmReturnToForm(0);
      handled = true; 
    }
    break;

  case lstSelectEvent:
    handled = true;
    selectedPlayer = e->data.lstSelect.selection;
    FrmPopupForm(IdFrmPlayer);
    break;

  default:
    break;
  }

  return handled;
}

/**
 * Player Form
 */
Boolean PlayerFormHandleEvent(EventPtr e)
{
  Boolean handled;
  static FormType *frm;
  struct player *player;
  static char dateBuffer[12];
  char *p;
  void *hBmp;
  
  handled = false;
  switch (e->eType) {

  case frmOpenEvent:
    frm = FrmGetActiveForm();
    player = (struct player*) items[selectedPlayer];
    DateToAscii(player->dateBirth.month,
		player->dateBirth.day,
		player->dateBirth.year+1904,
		defaultDateFormat,
		dateBuffer);
    p = GetString(IdPositionString+player->position);
    SetTextFieldWithString(Id2Ptr(IdFrmPlayer+1), player->name, false);
    SetTextFieldWithString(Id2Ptr(IdFrmPlayer+2), p, false);
    SetTextFieldWithString(Id2Ptr(IdFrmPlayer+3), player->team, false);
    SetTextFieldWithString(Id2Ptr(IdFrmPlayer+4), dateBuffer, false);
    FrmDrawForm(frm);
    if ( (hBmp = DmGetResource('Tbmp',IdPlayer+(selectedTeam-1)*25+selectedPlayer)) ) {
      WinDrawBitmap(MemHandleLock(hBmp),55,70);
      MemHandleUnlock(hBmp);
      DmReleaseResource(hBmp);
    }
    handled = true; 
    break;

  case ctlSelectEvent:
    if (e->data.ctlSelect.controlID == IdFrmPlayer) {
      FrmReturnToForm(0);
      handled = true; 
    }
    break;

  default:
    break;
  }

  return handled;
}

